{
  description = "SoraFlake";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixos-unstable";
    hardware.url = "github:nixos/nixos-hardware";
    nur.url = "github:nix-community/nur";

    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    darwin = {
      url = "github:lnl7/nix-darwin/master";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    hyprland.url = "github:hyprwm/Hyprland";
    sops-nix.url = "github:Mic92/sops-nix";
    nix-colors.url = "github:misterio77/nix-colors";

    snowfall-lib = {
      url = "github:snowfallorg/lib";
      inputs.nixpkgs.follows = "nixpkgs";
    };

  };

  outputs = inputs:
    let
      lib = inputs.snowfall-lib.mkLib {
        inherit inputs;
        src = ./.;
      };
    in lib.mkFlake {

      package-namespace = "custom";

      channels-config = {
        allowUnfree = true;
        permittedInsecurePackages = [ ];
      };

      systems = {
        modules = {
          darwin = with inputs; [ sops-nix.nixosModules.sops ];

          home = with inputs; [
            nix-colors.homeManagerModules
            hyprland.homeManagerModules
          ];

          nixos = with inputs; [ sops-nix.nixosModules.sops ];
        };
      };

    };

  # ===== Unsupported/NotImplemented ======
  # menel - PI/ARM64
  # ilduma - PI/ARM64
  # daimoth - PI/ARM64
  # gimle - ....

  # ===== Unused ======
  #
  # naraka - ?
  # diyu - ?
  # tirnanog - ?
  # valhalla - ?
  # arcadia - ? 
  # elysium - ? 
  # empyrean - ?
  # duat - ?
  # sheol - ?
  # adlivun - ?
  # araf - ?
  # aman/araman - ?

}
